@@ -23,15 +23,14 @@ class Mongo:
         try:
             client = MongoClient(self.config.get('host', '127.0.0.1'), self.config.get('port', 27017))
             db = client.get_database(self.config.get('db_name', ''))
-            user, pwd = self.config.get("db_user"), self.config.get("db_pwd")
+            user = self.config.get("db_user", '')
+            pwd = self.config.get("db_pwd", '')
             if user and pwd:
                 db.authenticate(user, pwd)
             return db
         except Exception as e:
             print(except_info(e))
-            print('connect to mongo error, system exit!')
-            sys.exit(0)
-            # return None
+            raise Exception('connect to mongo error!')
 
     def get_list(self, table, where={}, columns=None):
         try:
@@ -106,3 +105,6 @@ class Mongo:
         except Exception as e:
             print(except_info(e))
             return None
+
+mongo = Mongo({'host': '192.168.1.11', 'port': 27017, 'db_user': 'crawler', 'db_pwd': 'crawler11', 'db_name': 'crawler'})
+dis_res = mongo.get_list('dayi_disease_20220420', where={'disease_type': '2'})
\ No newline at end of file
